@@ -1,5 +1,7 @@
 """
-Main interface for sso-admin service literal definitions.
+Type annotations for sso-admin service literal definitions.
+
+[Open documentation](./literals.md)
 
 Usage::
 
